==> qtjambi-remoteobjects-6.2.11-sources.jar: io/qt/remoteobjects/QtROClientIoDevice.java <==
package io.qt.remoteobjects;


/**
 * <p>Java wrapper for Qt class QtROClientIoDevice</p>
 */
public abstract class QtROClientIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROClientIoDevice.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QtROClientIoDevice {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void connectToServer(){
            connectToServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void connectToServer_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        public io.qt.core.QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
        
        @Override
        @io.qt.QtUninvokable
        protected void doDisconnectFromServer(){
            doDisconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @io.qt.QtUninvokable
        private native void doDisconnectFromServer_native(long __this__nativeId);
        
    }
    

    public final Signal1<io.qt.remoteobjects.QtROClientIoDevice> shouldReconnect = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QtROClientIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROClientIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROClientIoDevice(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROClientIoDevice instance, io.qt.core.QObject parent);
    
    @io.qt.QtUninvokable
    public final void disconnectFromServer(){
        disconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void disconnectFromServer_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected final void setUrl(io.qt.core.QUrl url){
        setUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(url));
    }
    
    @io.qt.QtUninvokable
    private native void setUrl_native_cref_QUrl(long __this__nativeId, long url);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public abstract void connectToServer();
    
    @io.qt.QtUninvokable
    private native void connectToServer_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected java.lang.String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected abstract void doDisconnectFromServer();
    
    @io.qt.QtUninvokable
    private native void doDisconnectFromServer_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QtROClientIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QtROClientIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QtROClientIoDevice instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-6.2.12-sources.jar: io/qt/remoteobjects/QtROClientIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QtROClientIoDevice</p>
 */
public abstract class QtROClientIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROClientIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROClientIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void connectToServer(){
            connectToServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void connectToServer_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doDisconnectFromServer(){
            doDisconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doDisconnectFromServer_native(long __this__nativeId);
        
    }
    

    public final @NonNull Signal1<io.qt.remoteobjects.@Nullable QtROClientIoDevice> shouldReconnect = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROClientIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROClientIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROClientIoDevice instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    public final void disconnectFromServer(){
        disconnectFromServer_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void disconnectFromServer_native(long __this__nativeId);
    
    @QtUninvokable
    protected final void setUrl(io.qt.core.@NonNull QUrl url){
        setUrl_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(url));
    }
    
    @QtUninvokable
    private native void setUrl_native_cref_QUrl(long __this__nativeId, long url);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public abstract void connectToServer();
    
    @QtUninvokable
    private native void connectToServer_native(long __this__nativeId);
    
    @QtUninvokable
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    protected abstract void doDisconnectFromServer();
    
    @QtUninvokable
    private native void doDisconnectFromServer_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QtROClientIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROClientIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROClientIoDevice instance, QDeclarativeConstructor constructor);
    
}
